@@ -5,7 +5,7 @@
 
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
-;; URL: https://codeberg.org/ideasman42/emacs-hl-indent-scope-preset
+;; URL: https://codeberg.org/ideasman42/emacs-hl-indent-scope
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -16,20 +16,19 @@
 (eval-when-compile
   (require 'hl-indent-scope))
 
-(defun hl-indent-scope-preset-glsl--show-block-fn (_level)
-  "Callback for `hl-indent-scope-block-fn' at LEVEL.
-Return a tree in range BEG END."
+(defun hl-indent-scope-preset-glsl-mode--show-block-fn (_level)
+  "Callback for `hl-indent-scope-show-block-fn' at LEVEL."
   (declare (important-return-value t))
   (eq (char-before (point)) ?{))
 
 
 ;;;###autoload
 (defun hl-indent-scope-preset-glsl-mode (&rest args)
-  "Presets for `c-mode' with optional ARGS keyword arguments."
+  "Preset for `glsl-mode' with optional ARGS keyword arguments."
   (declare (important-return-value nil))
   (when args
-    (message "Currently ARGS isn't used!"))
-  (setq hl-indent-scope-show-block-fn 'hl-indent-scope-preset-glsl--show-block-fn))
+    (message "Currently ARGS aren't used!"))
+  (setq hl-indent-scope-show-block-fn 'hl-indent-scope-preset-glsl-mode--show-block-fn))
 
 (provide 'hl-indent-scope-preset-glsl-mode)
 ;; Local Variables:
